@@ -26,7 +26,8 @@ class TestCcp002v1(SDKBaseTest):
         self.assertEqual(expected, Ccp002v1._meta.description)
 
     def test_information(self):
-        expected = ('https://canvas-medical.zendesk.com/hc/en-us/articles/360059327893')
+        expected = (
+            'https://canvas-medical.zendesk.com/hc/en-us/articles/360059084173-COVID-19-Risk-Assessment-Follow-Up-Protocol')
         self.assertEqual(expected, Ccp002v1._meta.information)
 
     def test_change_types(self):
