@@ -23,17 +23,14 @@ class TestHcc003v1(SDKBaseTest):
     def test_description(self):
         expected = ('All patients with diabetes, uncomplicated AND a '
                     '2ndary condition often associated with diabetes.')
-        self.assertEqual(expected, Hcc003v1.description)
+        self.assertEqual(expected, Hcc003v1._meta.description)
 
     def test_information(self):
         expected = ('https://canvas-medical.zendesk.com/hc/en-us/articles/360057221174-Diabetes-Mellitus-With-Secondary-Complication-Suspect-HCC003v1')
-        self.assertEqual(expected, Hcc003v1.information)
-
-    def test_revision(self):
-        self.assertEqual('2019-02-12v1', Hcc003v1.revision())
+        self.assertEqual(expected, Hcc003v1._meta.information)
 
     def test_change_types(self):
-        result = Hcc003v1.compute_on_change_types
+        result = Hcc003v1._meta.compute_on_change_types
         expected = [
             'protocol_override',
             'condition',
