@@ -74,8 +74,11 @@ class CHANGE_TYPE:
     INTERVIEW = 'interview'
     "Recompute protocol when a patient's interview record has been updated."
 
+    LAB_ORDER = 'lab_order'
+    "Recompute protocol when a lab for a patient has been ordered"
+
     LAB_REPORT = 'lab_report'
-    "Recompute protocol when a lab order has been updated."
+    "Recompute protocol when a lab report has been created/updated."
 
     MEDICATION = 'medication'
     "Recompute protocol when a medication has been updated."
