@@ -22,6 +22,7 @@ from canvas_workflow_kit.patient_recordset import (
     InpatientStayRecordSet,
     InstructionRecordSet,
     InterviewRecordSet,
+    LabOrderRecordSet,
     LabReportRecordSet,
     MedicationRecordSet,
     MessageRecordSet,
@@ -73,6 +74,7 @@ class Patient:
         InpatientStayRecordSet,
         InstructionRecordSet,
         InterviewRecordSet,
+        LabOrderRecordSet,
         LabReportRecordSet,
         MedicationRecordSet,
         ProcedureRecordSet,
@@ -128,6 +130,9 @@ class Patient:
         self.interviews = InterviewRecordSet.new_from(
             data.get(InterviewRecordSet.API_UPDATE_FIELD, []))
 
+        self.lab_orders = LabOrderRecordSet.new_from(
+            data.get(LabOrderRecordSet.API_UPDATE_FIELD, []))
+
         self.lab_reports = LabReportRecordSet.new_from(
             data.get(LabReportRecordSet.API_UPDATE_FIELD, []))
 
