@@ -533,6 +533,10 @@ class VitalSignRecordSet(PatientEventRecordSet):
     def item_to_codes(item) -> List:
         return [{'code': item['loincNum'], 'system': URL_LOINC}]
 
+class LabOrderRecordSet(PatientEventRecordSet):
+    DATE_FIELD = 'dateOrdered'
+    PATIENT_FIELD = 'lab_orders'
+    API_UPDATE_FIELD = 'labOrders'
 
 class LabReportRecordSet(PatientEventRecordSet):
     VALID_SYSTEMS = ['loinc']
