@@ -1,15 +1,13 @@
-import glob
 import json
 import os
 
-from os.path import basename
 from unittest import TestCase
 
 from pathlib import Path
-from stringcase import camelcase
 
 from canvas_workflow_kit.patient import Patient
 from canvas_workflow_kit.protocol import ProtocolResult
+from canvas_workflow_kit.utils import load_local_patient
 
 
 class SDKBaseTest(TestCase):
@@ -24,44 +22,14 @@ class SDKBaseTest(TestCase):
             self.mocks_path = '.'
 
     def load_patient(self, patient_key) -> Patient:
-        data = {
-            'billingLineItems': [],
-            'conditions': [],
-            'imagingReports': [],
-            'immunizations': [],
-            'inpatient_stays': [],
-            'instructions': [],
-            'interviews': [],
-            'labReports': [],
-            'medications': [],
-            'referralReports': [],
-            'referrals': [],
-            'vitalSigns': [],
-            'patient': {},
-            'protocolOverrides': [],
-            'changeTypes': [],
-            'protocols': [],
-        }
 
-        file_loaded = False
         patient_path = Path(f'{self.mocks_path}/{patient_key}/')
 
         assert patient_path.is_dir(), f'no patient directory exists from {patient_path}'
 
-        for filepath in patient_path.glob('*.json'):
-            file_loaded = True
-
-            filename = str(basename(filepath))
-            field = camelcase(filename.split('.')[0])
-
-            with open(filepath, 'r') as fh:
-                data[field] = json.load(fh)
-
-        assert file_loaded, f'no JSON files were loaded from {patient_path}'
-
-        data['patient']['key'] = patient_key
-
-        return Patient(data)
+        patient = load_local_patient(patient_path)
+        patient.patient['key'] = patient_key
+        return patient
 
     def load_patient_data(self, patient_key, field):
         """
