@@ -32,6 +32,7 @@ class TestPatient(SDKBaseTest):
             'inpatient_stays',
             'instructions',
             'interviews',
+            'lab_orders',
             'lab_reports',
             'medications',
             'procedures',
@@ -60,6 +61,7 @@ class TestPatient(SDKBaseTest):
             'inpatient_stays': 0,
             'instructions': 0,
             'interviews': 1,
+            'lab_orders': 0,
             'lab_reports': 1,
             'medications': 1,
             'procedures': 0,
@@ -92,6 +94,7 @@ class TestPatient(SDKBaseTest):
             'inpatient_stays': 0,
             'instructions': 1,
             'interviews': 2,
+            'lab_orders': 1,
             'lab_reports': 2,
             'medications': 2,
             'procedures': 1,
@@ -124,6 +127,7 @@ class TestPatient(SDKBaseTest):
             'InpatientStayRecordSet',
             'InstructionRecordSet',
             'InterviewRecordSet',
+            'LabOrderRecordSet',
             'LabReportRecordSet',
             'MedicationRecordSet',
             'ProcedureRecordSet',
@@ -160,6 +164,7 @@ class TestPatient(SDKBaseTest):
             'inpatient_stays',
             'instructions',
             'interviews',
+            'lab_orders',
             'lab_reports',
             'medications',
             'procedures',
@@ -370,6 +375,7 @@ class TestPatient(SDKBaseTest):
             'immunizations',
             'instructions',
             'interviews',
+            'lab_orders',
             'lab_reports',
             'medications',
             'procedures',
