@@ -12,6 +12,7 @@ from canvas_workflow_kit.patient_recordset import (
     ImmunizationRecordSet,
     InstructionRecordSet,
     InterviewRecordSet,
+    LabOrderRecordSet,
     LabReportRecordSet,
     MedicationRecordSet,
     PatientEventRecordSet,
@@ -1187,6 +1188,15 @@ class TestVitalSignRecordSet(TestCase):
             'system': 'http://loinc.org'
         }], VitalSignRecordSet.item_to_codes(item))
 
+class TestLabORderRecordSet(TestCase):
+
+    def test_constants(self):
+        tested = LabOrderRecordSet([])
+        self.assertIsInstance(tested, PatientEventRecordSet)
+        self.assertEqual('dateOrdered', tested.DATE_FIELD)
+        self.assertEqual('lab_orders', tested.PATIENT_FIELD)
+        self.assertEqual('patient__key', tested.API_KEY_FIELD)
+        self.assertEqual('labOrders', tested.API_UPDATE_FIELD)
 
 class TestLabReportRecordSet(TestCase):
 
